@@ -50,6 +50,7 @@ import askFileDialog from './dialog/ask-file'
 import saveFileDialog from './dialog/save-dialog'
 import confirmRemove from './dialog/confirm-remove'
 import * as bcp47 from 'bcp-47'
+import mapFSError from './map-fs-error'
 
 export default class WindowManager extends EventEmitter {
   private _mainWindow: BrowserWindow|null
@@ -689,6 +690,17 @@ export default class WindowManager extends EventEmitter {
     })
   }
 
+  /**
+   * Reports an error specific to reading or writing files and directories.
+   *
+   * @param   {string}  title  A title for the error prompt (e.g. Error opening Workspace)
+   * @param   {any}     error  The error object that should be reported. Should be thrown by fs
+   */
+  reportFSError (title: string, error: any): void {
+    const { what, why } = mapFSError(error)
+    this.showErrorMessage(title, `There was an error accessing "${what}"`, why)
+  }
+
   /**
    * Opens the print window with the given file
    *
